@@ -2,7 +2,7 @@
 /*
  *  icmp.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,12 +29,13 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Sat 25 Oct 2008 05:26:03 JST
+ *  Last-modified: Tue 03 Nov 2009 21:53:03 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_ICMP_H
 #define CLX_ICMP_H
 
+#include "config.h"
 #include <cstring>
 #include <string>
 #include "ip.h"
@@ -109,16 +110,17 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		template <int Family>
 		class basic_socket : public basic_rawsocket<SOCK_RAW, Family, IPPROTO_ICMP> {
+		private:
+			typedef basic_rawsocket<SOCK_RAW, Family, IPPROTO_ICMP> super;
 		public:
-			typedef basic_rawsocket<SOCK_RAW, Family, IPPROTO_ICMP> rawsocket;
-			typedef basic_sockaddress<Family, IPPROTO_ICMP> sockaddress;
+			typedef basic_sockaddress<Family, IPPROTO_ICMP> address_type;
 			typedef char char_type;
 			typedef std::basic_string<char> string_type;
 			
-			basic_socket() : rawsocket(), from_(), to_() {}
+			basic_socket() : super(), from_(), to_() {}
 			
 			basic_socket(const basic_socket& cp) :
-				rawsocket(cp), from_(cp.from_), to_(cp.to_) {}
+				super(cp), from_(cp.from_), to_(cp.to_) {}
 			
 			basic_socket& operator=(const basic_socket& cp) {
 				from_ = cp.from_;
@@ -126,16 +128,16 @@ namespace clx {
 				this->assign(cp);
 			}
 			
-			explicit basic_socket(socket_int s, const sockaddress& addr) :
-				rawsocket(s), from_(), to_(addr) {}
+			explicit basic_socket(socket_int s, const address_type& addr) :
+				super(s), from_(), to_(addr) {}
 			
 			explicit basic_socket(const char_type* host) :
-				rawsocket(), from_(), to_() {
+				super(), from_(), to_() {
 				this->connect(host);
 			}
 			
 			explicit basic_socket(const string_type& host) :
-				rawsocket(), from_(), to_() {
+				super(), from_(), to_() {
 				this->connect(host);
 			}
 			
@@ -154,18 +156,18 @@ namespace clx {
 				return this->connect(host.c_str());
 			}
 			
-			int send_to(const char_type* src, int n, const sockaddress& addr) {
+			int send_to(const char_type* src, int n, const address_type& addr) {
 				struct icmphdr* ph = (struct icmphdr*)src;
 				ph->checksum = clx::ip::checksum((unsigned short*)src, n);
-				return ::sendto(this->socket(), src, n, 0, (struct sockaddr*)addr.data(), addr.size());
+				return sendto(this->socket(), src, n, 0, (struct sockaddr*)addr.data(), addr.size());
 			}
 			
-			int send_to(const string_type& src, const sockaddress& addr) {
+			int send_to(const string_type& src, const address_type& addr) {
 				return this->send_to(src.c_str(), src.size(), addr);
 			}
 			
 			int send_to(const char_type* src, int n, const char_type* host) {
-				sockaddress addr(host, 0);
+				address_type addr(host, 0);
 				return this->send_to(src, n, addr);
 			}
 			
@@ -182,22 +184,27 @@ namespace clx {
 			}
 			
 			int recv(char_type* dest, int n) {
-				typename sockaddress::inet_type tmp;
+				typename address_type::inet_type tmp;
 				int len = sizeof(tmp);
 				std::memset(dest, 0, n);
 				
-				int ret = ::recvfrom(this->socket(), dest, n, 0, (struct sockaddr*)&tmp, (socklen_type*)&len);
-				if (ret > 0) from_ = tmp;
+				int ret = recvfrom(this->socket(), dest, n, 0, (struct sockaddr*)&tmp, (socklen_type*)&len);
+				if (ret > 0) from_.assign(tmp);
 				return ret;
 			}
 			
+			template <std::size_t N>
+			int recv(char_type (&dest)[N]) {
+				return this->recv(dest, N);
+			}
+			
 			// accessor
-			const sockaddress& from() const { return from_; }
-			const sockaddress& to() const { return to_; }
+			const address_type& from() const { return from_; }
+			const address_type& to() const { return to_; }
 			
 		private:
-			sockaddress from_;
-			sockaddress to_;
+			address_type from_;
+			address_type to_;
 		};
 		
 		typedef basic_rawsocket<SOCK_RAW, AF_INET, IPPROTO_ICMP> rawsocket;
