@@ -2,7 +2,7 @@
 /*
  *  ssl.h
  *
- *  Copyright (c) 2004 - 2009, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2010, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -36,12 +36,13 @@
  *  The source code is derived from OpenSSL project.
  *  (See the following URL: http://www.openssl.org/source/license.html)
  *
- *  Last-modified: Tue 15 Dec 2009 17:59:03 JST
+ *  Last-modified: Wed 02 Jun 2010 04:26:03 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_SSL_H
 #define CLX_SSL_H
 
+#include "config.h"
 #include <ctime>
 #include <string>
 #include <stdexcept>
@@ -62,7 +63,7 @@
 #include <openssl/rand.h>
 
 #ifdef CLX_ENABLE_AUTOLINK
-#if defined(_MSC_VER) && (_MSC_VER >= 1200)
+#if defined(_MSC_VER) && (_MSC_VER >= 1200) || defined(__BORLANDC__)
 #pragma comment(lib, "libeay32.lib")
 #pragma comment(lib, "ssleay32.lib")
 #endif
@@ -414,24 +415,23 @@ namespace clx {
 				SSL_METHOD *(*f)() = NULL;
 				switch (Version) {
 				case sslv2:
-					if (mode == client) f = SSLv2_client_method;
-					else f = SSLv2_server_method;
+					if (mode == client) this->assign_ssl_method(SSLv2_client_method, f);
+					else this->assign_ssl_method(SSLv2_server_method, f);
 					break;
 				case sslv3:
-					if (mode == client) f = SSLv3_client_method;
-					else f = SSLv3_server_method;
+					if (mode == client) this->assign_ssl_method(SSLv3_client_method, f);
+					else this->assign_ssl_method(SSLv3_server_method, f);
 					break;
 				case tlsv1:
-					if (mode == client) f = TLSv1_client_method;
-					else f = TLSv1_server_method;
+					if (mode == client) this->assign_ssl_method(TLSv1_client_method, f);
+					else this->assign_ssl_method(TLSv1_server_method, f);
 					break;
 				case sslv23:
 				default:
-					if (mode == client) f = SSLv23_client_method;
-					else f = SSLv23_server_method;
+					if (mode == client) this->assign_ssl_method(SSLv23_client_method, f);
+					else this->assign_ssl_method(SSLv23_server_method, f);
 					break;
-				}
-				
+				}				
 				if (!p_->ctx()) p_->ctx() = SSL_CTX_new(f());
 				if (!p_->ctx()) throw std::runtime_error("SSL_CTX_new failed");
 				
@@ -457,6 +457,16 @@ namespace clx {
 				}
 				return this->handshake();
 			}
+			
+			template <class Source, class Type>
+			void assign_ssl_method(const Source* src, Type*& dest) {
+				dest = reinterpret_cast<Type*>(const_cast<Source*>(src));
+			}
+			
+			template <class Source, class Type>
+			void assign_ssl_method(Source* src, Type*& dest) {
+				dest = reinterpret_cast<Type*>(src);
+			}
 		};
 		
 		/* ----------------------------------------------------------------- */
@@ -529,7 +539,7 @@ namespace clx {
 			int nlisten_;
 			
 			basic_acceptor& start() {
-				if (super::open() < 0) throw socket_error("socket");
+				if (static_cast<int>(super::open()) < 0) throw socket_error("socket");
 				if (::bind(this->socket(), (struct sockaddr*)addr_.data(), addr_.size()) == -1) {
 					throw socket_error("bind");
 				}
