@@ -2,7 +2,7 @@
 /*
  *  udp.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,12 +29,13 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Sat 25 Oct 2008 05:35:00 JST
+ *  Last-modified: Tue 03 Nov 2009 21:59:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_UDP_H
 #define CLX_UDP_H
 
+#include "config.h"
 #include <cstdlib>
 #include <cstring>
 #include <string>
@@ -51,17 +52,18 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		template <int Family>
 		class basic_socket : public basic_rawsocket<SOCK_DGRAM, Family, 0> {
+		private:
+			typedef basic_rawsocket<SOCK_DGRAM, Family, 0> super;
 		public:
-			typedef basic_rawsocket<SOCK_DGRAM, Family, 0> rawsocket;
-			typedef basic_sockaddress<Family, IPPROTO_UDP> sockaddress;
+			typedef basic_sockaddress<Family, IPPROTO_UDP> address_type;
 			typedef char char_type;
 			typedef std::basic_string<char> string_type;
 			
 			// constructor and destructor
-			basic_socket() : rawsocket(), from_(), to_(), is_bind_(false) {}
+			basic_socket() : super(), from_(), to_(), is_bind_(false) {}
 			
 			basic_socket(const basic_socket& cp) :
-				rawsocket(cp), from_(cp.from_), to_(cp.to_), is_bind_(cp.is_bind_) {}
+				super(cp), from_(cp.from_), to_(cp.to_), is_bind_(cp.is_bind_) {}
 			
 			basic_socket& operator=(const basic_socket& cp) {
 				from_ = cp.from_;
@@ -70,21 +72,21 @@ namespace clx {
 				this->assign(cp);
 			}
 			
-			explicit basic_socket(socket_int s, const sockaddress& addr) :
-				rawsocket(s), from_(), to_(addr), is_bind_(false) {}
+			explicit basic_socket(socket_int s, const address_type& addr) :
+				super(s), from_(), to_(addr), is_bind_(false) {}
 			
 			explicit basic_socket(const char_type* host, int port) :
-				rawsocket(), from_(), to_(), is_bind_(false) {
+				super(), from_(), to_(), is_bind_(false) {
 				this->connect(host, port);
 			}
 			
 			explicit basic_socket(const string_type& host, int port) :
-				rawsocket(), from_(), to_(), is_bind_(false) {
+				super(), from_(), to_(), is_bind_(false) {
 				this->connect(host, port);
 			}
 			
 			explicit basic_socket(int port) :
-				rawsocket(), from_(), to_(), is_bind_(false) {
+				super(), from_(), to_(), is_bind_(false) {
 				this->bind(port);
 			}
 			
@@ -105,62 +107,6 @@ namespace clx {
 			
 			basic_socket& bind(int port) {
 				to_.assign(port);
-				return this->xbind();
-			}
-			
-			int send_to(const char_type* src, int n, const sockaddress& addr) {
-				return sendto(this->socket(), src, n, 0, (struct sockaddr*)addr.data(), addr.size());
-			}
-			
-			int send_to(const string_type& src, const sockaddress& addr) {
-				return this->send_to(src.c_str(), src.size(), addr);
-			}
-			
-			int send_to(const char_type* src, int n, const char_type* host, int port) {
-				sockaddress addr(host, port);
-				return this->send_to(src, n, addr);
-			}
-			
-			int send_to(const string_type& src, const string_type& host, int port) {
-				sockaddress addr(host, port);
-				return this->send_to(src, addr);
-			}
-			
-			virtual int send(const char_type* src, int n) {
-				int len = -1;
-				
-				if (!this->is_bind()) len = this->send_to(src, n, to_);
-				else len = this->send_to(src, n, from_);
-				return len;
-			}
-			
-			virtual int send(const string_type& src) {
-				return this->send(src.c_str(), src.size());
-			}
-			
-			virtual int recv(char_type* dest, int n) {
-				if (!this->is_bind()) return -1;
-				
-				typename sockaddress::inet_type tmp;
-				int len = sizeof(tmp);
-				std::memset(dest, 0, n);
-				
-				int ret = recvfrom(this->socket(), dest, n, 0, (struct sockaddr*)&tmp, (socklen_type*)&len);
-				if (ret > 0) from_ = tmp;
-				return ret;
-			}
-			
-			// accessor
-			bool is_bind() const { return is_bind_; }
-			const sockaddress& from() const { return from_; }
-			const sockaddress& to() const { return to_; }
-			
-		private:
-			sockaddress from_;
-			sockaddress to_;
-			bool is_bind_;
-			
-			basic_socket& xbind() {
 				if (this->is_open()) this->close();
 				this->open();
 				
@@ -172,6 +118,63 @@ namespace clx {
 				is_bind_ = true;
 				return *this;
 			}
+			
+			int send_to(const char_type* src, int n, const address_type& addr) {
+				return sendto(this->socket(), src, n, 0, (struct sockaddr*)addr.data(), addr.size());
+			}
+			
+			int send_to(const string_type& src, const address_type& addr) {
+				return this->send_to(src.c_str(), src.size(), addr);
+			}
+			
+			int send_to(const char_type* src, int n, const char_type* host, int port) {
+				address_type addr(host, port);
+				return this->send_to(src, n, addr);
+			}
+			
+			int send_to(const string_type& src, const string_type& host, int port) {
+				address_type addr(host, port);
+				return this->send_to(src, addr);
+			}
+			
+			int send(const char_type* src, int n) {
+				int len = -1;
+				
+				if (!this->is_bind()) len = this->send_to(src, n, to_);
+				else len = this->send_to(src, n, from_);
+				return len;
+			}
+			
+			int send(const string_type& src) {
+				return this->send(src.c_str(), src.size());
+			}
+			
+			int recv(char_type* dest, int n) {
+				if (!this->is_bind()) return -1;
+				
+				typename address_type::inet_type tmp;
+				int len = sizeof(tmp);
+				std::memset(dest, 0, n);
+				
+				int ret = recvfrom(this->socket(), dest, n, 0, (struct sockaddr*)&tmp, (socklen_type*)&len);
+				if (ret > 0) from_.assign(tmp);
+				return ret;
+			}
+			
+			template <std::size_t N>
+			int recv(char_type (&dest)[N]) {
+				return this->recv(dest, N);
+			}
+			
+			// accessor
+			bool is_bind() const { return is_bind_; }
+			const address_type& from() const { return from_; }
+			const address_type& to() const { return to_; }
+			
+		private:
+			address_type from_;
+			address_type to_;
+			bool is_bind_;
 		};
 		
 		/* ----------------------------------------------------------------- */
