@@ -2,7 +2,7 @@
 /*
  *  unit.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,12 +29,14 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Thu 04 Sep 2008 15:48:00 JST
+ *  Last-modified: Tue 22 Sep 2009 16:27:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_UNIT_H
 #define CLX_UNIT_H
 
+#include "config.h"
+
 namespace clx {
 	/* --------------------------------------------------------------------- */
 	//  unit
@@ -111,8 +113,22 @@ namespace clx {
 	typedef unit<   1000000, 1> mega;
 	typedef unit<1000000000, 1> giga;
 	
-	// frequently used in computer fields
-	typedef unit<8, 1> byte;
+	// frequently used unit.
+	typedef unit<8, 1>   byte;
+	typedef unit<1, 100> percent;
+	
+	/* --------------------------------------------------------------------- */
+	//  convert degree <-> radian
+	/* --------------------------------------------------------------------- */
+	inline double degree(double rad) {
+		static const double pi = 3.141592653589793;
+		return rad * 180.0 / pi;
+	}
+	
+	inline double radian(double deg) {
+		static const double pi = 3.141592653589793;
+		return deg * pi / 180.0;
+	}
 }
 
 #endif // CLX_UNIT_H
