@@ -473,7 +473,7 @@ typedef struct
 
 local int unzlocal_getByte(const zlib_filefunc_def* pzlib_filefunc_def, voidpf filestream, int *pi)
 {
-    unsigned char c;
+    unsigned char c = 0;
     int err = (int)ZREAD(*pzlib_filefunc_def,filestream,&c,1);
     if (err==1)
     {
@@ -495,9 +495,9 @@ local int unzlocal_getByte(const zlib_filefunc_def* pzlib_filefunc_def, voidpf f
 */
 local int unzlocal_getShort (const zlib_filefunc_def* pzlib_filefunc_def, voidpf filestream, uLong *pX)
 {
-    uLong x ;
-    int i;
-    int err;
+    uLong x = 0;
+    int i = 0;
+    int err = 0;
 
     err = unzlocal_getByte(pzlib_filefunc_def,filestream,&i);
     x = (uLong)i;
@@ -515,9 +515,9 @@ local int unzlocal_getShort (const zlib_filefunc_def* pzlib_filefunc_def, voidpf
 
 local int unzlocal_getLong (const zlib_filefunc_def* pzlib_filefunc_def, voidpf filestream, uLong *pX)
 {
-    uLong x ;
-    int i;
-    int err;
+    uLong x = 0;
+    int i = 0;
+    int err = 0;
 
     err = unzlocal_getByte(pzlib_filefunc_def,filestream,&i);
     x = (uLong)i;
@@ -605,8 +605,8 @@ inline int ZEXPORT unzStringFileNameCompare (const char* fileName1, const char*
 local uLong unzlocal_SearchCentralDir(const zlib_filefunc_def* pzlib_filefunc_def, voidpf filestream)
 {
     unsigned char* buf;
-    uLong uSizeFile;
-    uLong uBackRead;
+    uLong uSizeFile=0;
+    uLong uBackRead=0;
     uLong uMaxBack=0xffff; /* maximum size of global comment */
     uLong uPosFound=0;
 
@@ -669,16 +669,16 @@ local uLong unzlocal_SearchCentralDir(const zlib_filefunc_def* pzlib_filefunc_de
 inline unzFile ZEXPORT unzOpen2 (const char *path, zlib_filefunc_def* pzlib_filefunc_def)
 {
     unz_s us;
-    unz_s *s;
-    uLong central_pos,uL;
+    unz_s *s=NULL;
+    uLong central_pos=0,uL=0;
 
-    uLong number_disk;          /* number of the current dist, used for
-                                   spaning ZIP, unsupported, always 0*/
-    uLong number_disk_with_CD;  /* number the the disk with central dir, used
-                                   for spaning ZIP, unsupported, always 0*/
-    uLong number_entry_CD;      /* total number of entries in
-                                   the central dir
-                                   (same than number_entry on nospan) */
+    uLong number_disk=0;         /* number of the current dist, used for
+                                    spaning ZIP, unsupported, always 0*/
+    uLong number_disk_with_CD=0; /* number the the disk with central dir, used
+                                    for spaning ZIP, unsupported, always 0*/
+    uLong number_entry_CD=0;     /* total number of entries in
+                                    the central dir
+                                    (same than number_entry on nospan) */
 
     int err=UNZ_OK;
 
@@ -779,7 +779,7 @@ inline unzFile ZEXPORT unzOpen (const char *path)
   return UNZ_OK if there is no problem. */
 inline int ZEXPORT unzClose (unzFile file)
 {
-    unz_s* s;
+    unz_s* s=NULL;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -798,7 +798,7 @@ inline int ZEXPORT unzClose (unzFile file)
   return UNZ_OK if there is no problem. */
 inline int ZEXPORT unzGetGlobalInfo (unzFile file, unz_global_info *pglobal_info)
 {
-    unz_s* s;
+    unz_s* s=NULL;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -811,7 +811,7 @@ inline int ZEXPORT unzGetGlobalInfo (unzFile file, unz_global_info *pglobal_info
 */
 local void unzlocal_DosDateToTmuDate (uLong ulDosDate, tm_unz* ptm)
 {
-    uLong uDate;
+    uLong uDate=0;
     uDate = (uLong)(ulDosDate>>16);
     ptm->tm_mday = (uInt)(uDate&0x1f) ;
     ptm->tm_mon =  (uInt)((((uDate)&0x1E0)/0x20)-1) ;
@@ -832,11 +832,11 @@ local int unzlocal_GetCurrentFileInfoInternal (unzFile file,
                                               void *extraField, uLong extraFieldBufferSize,
                                               char *szComment,  uLong commentBufferSize)
 {
-    unz_s* s;
+    unz_s* s=NULL;
     unz_file_info file_info;
     unz_file_info_internal file_info_internal;
     int err=UNZ_OK;
-    uLong uMagic;
+    uLong uMagic=0;
     long lSeek=0;
 
     if (file==NULL)
@@ -849,12 +849,13 @@ local int unzlocal_GetCurrentFileInfoInternal (unzFile file,
 
 
     /* we check the magic */
-    if (err==UNZ_OK)
+    if (err==UNZ_OK) {
         if (unzlocal_getLong(&s->z_filefunc, s->filestream,&uMagic) != UNZ_OK)
             err=UNZ_ERRNO;
         else if (uMagic!=0x02014b50)
             err=UNZ_BADZIPFILE;
-
+	}
+	
     if (unzlocal_getShort(&s->z_filefunc, s->filestream,&file_info.version) != UNZ_OK)
         err=UNZ_ERRNO;
 
@@ -929,11 +930,13 @@ local int unzlocal_GetCurrentFileInfoInternal (unzFile file,
         else
             uSizeRead = extraFieldBufferSize;
 
-        if (lSeek!=0)
+        if (lSeek!=0) {
             if (ZSEEK(s->z_filefunc, s->filestream,lSeek,ZLIB_FILEFUNC_SEEK_CUR)==0)
                 lSeek=0;
             else
                 err=UNZ_ERRNO;
+        }
+        
         if ((file_info.size_file_extra>0) && (extraFieldBufferSize>0))
             if (ZREAD(s->z_filefunc, s->filestream,extraField,uSizeRead)!=uSizeRead)
                 err=UNZ_ERRNO;
@@ -954,11 +957,13 @@ local int unzlocal_GetCurrentFileInfoInternal (unzFile file,
         else
             uSizeRead = commentBufferSize;
 
-        if (lSeek!=0)
+        if (lSeek!=0) {
             if (ZSEEK(s->z_filefunc, s->filestream,lSeek,ZLIB_FILEFUNC_SEEK_CUR)==0)
                 lSeek=0;
             else
                 err=UNZ_ERRNO;
+        }
+        
         if ((file_info.size_file_comment>0) && (commentBufferSize>0))
             if (ZREAD(s->z_filefunc, s->filestream,szComment,uSizeRead)!=uSizeRead)
                 err=UNZ_ERRNO;
@@ -1000,7 +1005,7 @@ inline int ZEXPORT unzGetCurrentFileInfo (unzFile file,
 inline int ZEXPORT unzGoToFirstFile (unzFile file)
 {
     int err=UNZ_OK;
-    unz_s* s;
+    unz_s* s=NULL;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -1020,8 +1025,8 @@ inline int ZEXPORT unzGoToFirstFile (unzFile file)
 */
 inline int ZEXPORT unzGoToNextFile (unzFile file)
 {
-    unz_s* s;
-    int err;
+    unz_s* s=NULL;
+    int err=0;
 
     if (file==NULL)
         return UNZ_PARAMERROR;
@@ -1052,8 +1057,8 @@ inline int ZEXPORT unzGoToNextFile (unzFile file)
 */
 inline int ZEXPORT unzLocateFile (unzFile file, const char *szFileName, int iCaseSensitivity)
 {
-    unz_s* s;
-    int err;
+    unz_s* s=NULL;
+    int err=0;
 
     /* We remember the 'current' position in the file so that we can jump
      * back there if we fail.
@@ -1126,7 +1131,7 @@ typedef struct unz_file_pos_s
 
 inline int ZEXPORT unzGetFilePos(unzFile file, unz_file_pos* file_pos)
 {
-    unz_s* s;
+    unz_s* s=NULL;
 
     if (file==NULL || file_pos==NULL)
         return UNZ_PARAMERROR;
@@ -1142,8 +1147,8 @@ inline int ZEXPORT unzGetFilePos(unzFile file, unz_file_pos* file_pos)
 
 inline int ZEXPORT unzGoToFilePos(unzFile file, unz_file_pos* file_pos)
 {
-    unz_s* s;
-    int err;
+    unz_s* s=NULL;
+    int err=0;
 
     if (file==NULL || file_pos==NULL)
         return UNZ_PARAMERROR;
@@ -1178,9 +1183,9 @@ local int unzlocal_CheckCurrentFileCoherencyHeader (unz_s* s, uInt* piSizeVar,
                                                     uLong *poffset_local_extrafield,
                                                     uInt  *psize_local_extrafield)
 {
-    uLong uMagic,uData,uFlags;
-    uLong size_filename;
-    uLong size_extra_field;
+    uLong uMagic=0,uData=0,uFlags=0;
+    uLong size_filename=0;
+    uLong size_extra_field=0;
     int err=UNZ_OK;
 
     *piSizeVar = 0;
@@ -1192,12 +1197,13 @@ local int unzlocal_CheckCurrentFileCoherencyHeader (unz_s* s, uInt* piSizeVar,
         return UNZ_ERRNO;
 
 
-    if (err==UNZ_OK)
+    if (err==UNZ_OK) {
         if (unzlocal_getLong(&s->z_filefunc, s->filestream,&uMagic) != UNZ_OK)
             err=UNZ_ERRNO;
         else if (uMagic!=0x04034b50)
             err=UNZ_BADZIPFILE;
-
+	}
+	
     if (unzlocal_getShort(&s->z_filefunc, s->filestream,&uData) != UNZ_OK)
         err=UNZ_ERRNO;
 /*
@@ -1263,11 +1269,11 @@ local int unzlocal_CheckCurrentFileCoherencyHeader (unz_s* s, uInt* piSizeVar,
 inline int ZEXPORT unzOpenCurrentFile3 (unzFile file, int* method, int* level, int raw, const char* password)
 {
     int err=UNZ_OK;
-    uInt iSizeVar;
-    unz_s* s;
-    file_in_zip_read_info_s* pfile_in_zip_read_info;
-    uLong offset_local_extrafield;  /* offset of the local extra field */
-    uInt  size_local_extrafield;    /* size of the local extra field */
+    uInt iSizeVar=0;
+    unz_s* s=NULL;
+    file_in_zip_read_info_s* pfile_in_zip_read_info=NULL;
+    uLong offset_local_extrafield=0;  /* offset of the local extra field */
+    uInt  size_local_extrafield=0;    /* size of the local extra field */
 #    ifndef NOUNCRYPT
     char source[12];
 #    else
@@ -1430,7 +1436,7 @@ inline int ZEXPORT unzReadCurrentFile  (unzFile file, voidp buf, unsigned len)
 {
     int err=UNZ_OK;
     uInt iRead = 0;
-    unz_s* s;
+    unz_s* s = NULL;
     file_in_zip_read_info_s* pfile_in_zip_read_info;
     if (file==NULL) {
         return UNZ_PARAMERROR;
@@ -1587,7 +1593,7 @@ inline int ZEXPORT unzReadCurrentFile  (unzFile file, voidp buf, unsigned len)
 */
 inline z_off_t ZEXPORT unztell (unzFile file)
 {
-    unz_s* s;
+    unz_s* s=NULL;
     file_in_zip_read_info_s* pfile_in_zip_read_info;
     if (file==NULL)
         return UNZ_PARAMERROR;
@@ -1605,8 +1611,8 @@ inline z_off_t ZEXPORT unztell (unzFile file)
 */
 inline int ZEXPORT unzeof (unzFile file)
 {
-    unz_s* s;
-    file_in_zip_read_info_s* pfile_in_zip_read_info;
+    unz_s* s=NULL;
+    file_in_zip_read_info_s* pfile_in_zip_read_info=NULL;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -1635,10 +1641,10 @@ inline int ZEXPORT unzeof (unzFile file)
 */
 inline int ZEXPORT unzGetLocalExtrafield (unzFile file, voidp buf, unsigned int len)
 {
-    unz_s* s;
-    file_in_zip_read_info_s* pfile_in_zip_read_info;
-    uInt read_now;
-    uLong size_to_read;
+    unz_s* s=NULL;
+    file_in_zip_read_info_s* pfile_in_zip_read_info=NULL;
+    uInt read_now=0;
+    uLong size_to_read=0;
 
     if (file==NULL)
         return UNZ_PARAMERROR;
@@ -1685,8 +1691,8 @@ inline int ZEXPORT unzCloseCurrentFile (unzFile file)
 {
     int err=UNZ_OK;
 
-    unz_s* s;
-    file_in_zip_read_info_s* pfile_in_zip_read_info;
+    unz_s* s=NULL;
+    file_in_zip_read_info_s* pfile_in_zip_read_info=NULL;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -1725,8 +1731,8 @@ inline int ZEXPORT unzCloseCurrentFile (unzFile file)
 inline int ZEXPORT unzGetGlobalComment (unzFile file, char *szComment, uLong uSizeBuf)
 {
     // int err=UNZ_OK; // comment out by clown (2009/06/01)
-    unz_s* s;
-    uLong uReadThis ;
+    unz_s* s=NULL;
+    uLong uReadThis=0 ;
     if (file==NULL)
         return UNZ_PARAMERROR;
     s=(unz_s*)file;
@@ -1753,7 +1759,7 @@ inline int ZEXPORT unzGetGlobalComment (unzFile file, char *szComment, uLong uSi
 /* Additions by RX '2004 */
 inline uLong ZEXPORT unzGetOffset (unzFile file)
 {
-    unz_s* s;
+    unz_s* s=NULL;
 
     if (file==NULL)
           return (uLong)UNZ_PARAMERROR;
@@ -1768,8 +1774,8 @@ inline uLong ZEXPORT unzGetOffset (unzFile file)
 
 inline int ZEXPORT unzSetOffset (unzFile file, uLong pos)
 {
-    unz_s* s;
-    int err;
+    unz_s* s=NULL;
+    int err=0;
 
     if (file==NULL)
         return UNZ_PARAMERROR;
